import React, { useState } from "react";
import Login from "../components/Login";

import SignUp from "../components/SignUp";
import COVER from "../res/cover.svg";
import { USER_TYPE } from "../common/types";
import Alert from "../components/Alert";

const Landing = () => {
  const [alert, setAlert] = useState<string | null>(null);
  const [userType, setUserType] = useState<USER_TYPE>(USER_TYPE.CANDIDATE);
  const [form, setForm] = useState<"sign-in" | "sign-up">("sign-up");

  const setCandidate = () => setUserType(USER_TYPE.CANDIDATE);
  const setOrganization = () => setUserType(USER_TYPE.ORGANIZATION);

  const candidateClassName =
    userType === USER_TYPE.CANDIDATE ? "btn" : "btn deactive";

  const organizationClassName =
    userType === USER_TYPE.ORGANIZATION ? "btn active" : "btn deactive";

  const renderForm =
    form === "sign-up" ? (
      <>
        <SignUp userType={userType} setAlert={setAlert} setForm={setForm} />
        <section>
          <p>
            Already have an account?
            <button
              type="button"
              className="btn btn-link"
              onClick={() => setForm("sign-in")}
            >
              Sign in
            </button>
          </p>
        </section>
      </>
    ) : (
      <>
        <Login userType={userType} setAlert={setAlert} />
        <section>
          <p>
            New to Smart Recruiter?
            <button
              type="button"
              className="btn btn-link"
              onClick={() => setForm("sign-up")}
            >
              Sign up
            </button>
          </p>
        </section>
      </>
    );

  return (
    <div className="landing">
      <div className="container">
        <div className="row">
          <div className="col-6  mt-5">
            <img src={COVER} alt="cover" />
          </div>
          <div className="col-6">
            <div className="card card-body onboard p-4">
              <div className="usertype-selector btn-group" role="group">
                <button
                  type="button"
                  className={candidateClassName}
                  onClick={setCandidate}
                >
                  Candidate
                </button>
                <button
                  type="button"
                  className={organizationClassName}
                  onClick={setOrganization}
                >
                  Organization
                </button>
              </div>

              {renderForm}
              <Alert alert={alert} setAlert={setAlert} />
            </div>
          </div>
        </div>
        <div className="row" style={{ paddingBottom: "100px" }}>
          <h1 className="display-6">Smart Recruiter </h1>
          <p className="lead">
            Lorem ipsum dolor sit amet consectetur, adipisicing elit. At quae
            saepe temporibus recusandae illo ex in voluptatibus assumenda
            delectus sunt autem culpa ratione, ipsa totam magni ducimus eaque
            quisquam. Harum!
          </p>
        </div>
      </div>
    </div>
  );
};

export default Landing;
